package de.mannheim.ids.sruws;

import java.util.HashMap;
import java.util.Map;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.xml.sax.Attributes;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.DefaultHandler;

public class SRUScanResonseHandler extends DefaultHandler{
	
	private Map<String, Corpus> corpora;
	private boolean isSruTerm, isSruValue, isSruDisplayTerm; 
	private String pid, name;
	
	private Logger logger = (Logger) LoggerFactory.getLogger(SRUScanResonseHandler.class);
	
	public SRUScanResonseHandler() {
		corpora = new HashMap<String, Corpus>(); 
		pid = ""; 
		name = "";
	}
	
	@Override
	public void startElement(String uri, String localName, String qName,
			Attributes attributes) throws SAXException {
		// TODO Auto-generated method stub
		
		if (qName.equalsIgnoreCase("sru:term")){
			isSruTerm = true;
		}
		else if (qName.equalsIgnoreCase("sru:value")){
			isSruValue = true;
		}
		else if (qName.equalsIgnoreCase("sru:displayTerm")){
			isSruDisplayTerm = true;
		}		
	}
	
	@Override
	public void endElement(String uri, String localName, String qName)
			throws SAXException {
	
		if (qName.equalsIgnoreCase("sru:term")){
			isSruTerm = false;
			logger.info("Corpus {} pid {}",name,pid);
			corpora.put(pid, new Corpus(pid, name));
			pid=""; name="";
		}
		else if (qName.equalsIgnoreCase("sru:value")){
			isSruValue = false;
		}
		else if (qName.equalsIgnoreCase("sru:displayTerm")){
			isSruDisplayTerm = false;
		}		
	}
	
	@Override
	public void characters(char[] ch, int start, int length)
			throws SAXException {
		
		if (isSruTerm && isSruValue){
			pid += new String(ch, start, length);
		}
		else if (isSruTerm && isSruDisplayTerm){
			name += new String(ch, start, length);
		}
	}
	
	
	public Map<String, Corpus> getCorpora() {
		return corpora;
	}

	public void setCorpora(Map<String, Corpus> corpora) {
		this.corpora = corpora;
	}
}
